from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from webdriver_manager.chrome import ChromeDriverManager
import pandas as pd
import logging

# Setup logging
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

# WebDriver 서비스 설정
service = Service(ChromeDriverManager().install())

# WebDriver 설정
options = webdriver.ChromeOptions()
# options.add_argument('--headless')  # Headless 모드로 실행 (디버깅을 위해 주석 처리)
options.add_argument('--no-sandbox')
options.add_argument('--disable-dev-shm-usage')

# WebDriver 초기화
try:
    driver = webdriver.Chrome(service=service, options=options)
    logger.info("WebDriver initialized successfully.")
except Exception as e:
    logger.error(f"Error initializing WebDriver: {e}")
    raise

try:
    # 메인 페이지 URL
    main_url = 'https://apiportal.koreainvestment.com/apiservice'
    logger.info(f"Loading main page: {main_url}")

    # 메인 페이지 로드
    driver.get(main_url)
    WebDriverWait(driver, 10).until(EC.presence_of_element_located((By.TAG_NAME, 'a')))

    # 하위 링크들을 추출
    links = []
    a_tags = driver.find_elements(By.TAG_NAME, 'a')
    for a_tag in a_tags:
        href = a_tag.get_attribute('href')
        if href and 'http' in href and 'api' in href.lower():
            links.append(href)

    logger.info(f"Found {len(links)} links related to API on the main page: {links}")

    # 각 링크의 내용을 가져와 리스트에 저장
    data = []
    for i, link in enumerate(links):
        try:
            logger.info(f"Processing link {i+1}/{len(links)}: {link}")
            driver.get(link)
            WebDriverWait(driver, 10).until(EC.presence_of_element_located((By.TAG_NAME, 'body')))
            # 페이지의 텍스트를 모두 가져옴
            page_text = driver.find_element(By.TAG_NAME, 'body').text
            data.append({
                'link': link,
                'content': page_text.strip()
            })
        except Exception as e:
            logger.error(f"Failed to retrieve {link}: {e}")

finally:
    # WebDriver 종료
    logger.info("Quitting WebDriver.")
    driver.quit()

# pandas DataFrame으로 변환
df = pd.DataFrame(data)

# CSV 파일로 저장 (F 드라이브에 저장하도록 경로 수정)
csv_path = r'F:\web_contents.csv'
df.to_csv(csv_path, index=False, encoding='utf-8')

logger.info(f"CSV 파일이 성공적으로 {csv_path}에 저장되었습니다!")
